==> gtkmathview_0.6.5.orig.tar.gz: gtkmathview-0.6.5/src/frontend/common/Builder.cc <==
// Copyright (C) 2000-2004, Luca Padovani <luca.padovani@cs.unibo.it>.
//
// This file is part of GtkMathView, a Gtk widget for MathML.
// 
// GtkMathView is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// GtkMathView is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GtkMathView; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// For details, see the GtkMathView World-Wide-Web page,
// http://helm.cs.unibo.it/mml-widget/, or send a mail to
// <lpadovan@cs.unibo.it>

#include <config.h>

#include "Builder.hh"
#include "AbstractLogger.hh"
#include "MathMLNamespaceContext.hh"
#if ENABLE_BOXML
#include "BoxMLNamespaceContext.hh"
#endif // ENABLE_BOXML

Builder::Builder()
{ }

Builder::~Builder()
{ }

void
Builder::setMathMLNamespaceContext(const SmartPtr<MathMLNamespaceContext>& ctxt)
{ mathmlContext = ctxt; }

SmartPtr<MathMLNamespaceContext>
Builder::getMathMLNamespaceContext() const
{ return mathmlContext; }

#if ENABLE_BOXML
void
Builder::setBoxMLNamespaceContext(const SmartPtr<BoxMLNamespaceContext>& ctxt)
{ boxmlContext = ctxt; }

SmartPtr<BoxMLNamespaceContext>
Builder::getBoxMLNamespaceContext() const
{ return boxmlContext; }
#endif // ENABLE_BOXML

void
Builder::setLogger(const SmartPtr<AbstractLogger>& l)
{ logger = l; }

SmartPtr<AbstractLogger>
Builder::getLogger() const
{ return logger; }

==> gtkmathview_0.7.7.orig.tar.gz: gtkmathview-0.7.7/src/frontend/common/Builder.cc <==
// Copyright (C) 2000-2004, Luca Padovani <luca.padovani@cs.unibo.it>.
//
// This file is part of GtkMathView, a Gtk widget for MathML.
// 
// GtkMathView is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// GtkMathView is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with GtkMathView; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// 
// For details, see the GtkMathView World-Wide-Web page,
// http://helm.cs.unibo.it/mml-widget/, or send a mail to
// <lpadovan@cs.unibo.it>

#include <config.h>

#include "Builder.hh"
#include "AbstractLogger.hh"
#include "MathMLNamespaceContext.hh"
#if GMV_ENABLE_BOXML
#include "BoxMLNamespaceContext.hh"
#endif // GMV_ENABLE_BOXML

Builder::Builder()
{ }

Builder::~Builder()
{ }

void
Builder::setMathMLNamespaceContext(const SmartPtr<MathMLNamespaceContext>& ctxt)
{ mathmlContext = ctxt; }

SmartPtr<MathMLNamespaceContext>
Builder::getMathMLNamespaceContext() const
{ return mathmlContext; }

#if GMV_ENABLE_BOXML
void
Builder::setBoxMLNamespaceContext(const SmartPtr<BoxMLNamespaceContext>& ctxt)
{ boxmlContext = ctxt; }

SmartPtr<BoxMLNamespaceContext>
Builder::getBoxMLNamespaceContext() const
{ return boxmlContext; }
#endif // GMV_ENABLE_BOXML

void
Builder::setLogger(const SmartPtr<AbstractLogger>& l)
{ logger = l; }

SmartPtr<AbstractLogger>
Builder::getLogger() const
{ return logger; }
